pub struct RequestHead {
pub method: HttpMethod,
pub uri: String,
pub headers: BTreeMap<String, String>,
}Fields
method: HttpMethoduri: Stringheaders: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for RequestHead
impl Clone for RequestHead
Sourcefn clone(&self) -> RequestHead
fn clone(&self) -> RequestHead
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestHead
impl Debug for RequestHead
Sourceimpl Decode for RequestHead
impl Decode for RequestHead
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for RequestHead
impl Encode for RequestHead
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl PartialEq for RequestHead
impl PartialEq for RequestHead
Sourcefn eq(&self, other: &RequestHead) -> bool
fn eq(&self, other: &RequestHead) -> bool
Tests for
self and other values to be equal, and is used by ==.impl EncodeLike for RequestHead
impl Eq for RequestHead
impl StructuralPartialEq for RequestHead