pub struct ResponseHead {
pub status: u16,
pub headers: BTreeMap<String, String>,
}Fields
status: u16headers: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for ResponseHead
impl Clone for ResponseHead
Sourcefn clone(&self) -> ResponseHead
fn clone(&self) -> ResponseHead
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseHead
impl Debug for ResponseHead
Sourceimpl Decode for ResponseHead
impl Decode for ResponseHead
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for ResponseHead
impl Encode for ResponseHead
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl PartialEq for ResponseHead
impl PartialEq for ResponseHead
Sourcefn eq(&self, other: &ResponseHead) -> bool
fn eq(&self, other: &ResponseHead) -> bool
Tests for
self and other values to be equal, and is used by ==.impl EncodeLike for ResponseHead
impl Eq for ResponseHead
impl StructuralPartialEq for ResponseHead